==> percona-xtrabackup-8.0.30-23.tar.gz: percona-xtrabackup-8.0.30-23/storage/ndb/clusterj/clusterj-test/src/main/java/testsuite/clusterj/model/CharsetSwedishUtf8.java <==
/*
 *  Copyright (c) 2014, 2022, Oracle and/or its affiliates.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2.0,
 *  as published by the Free Software Foundation.
 *
 *  This program is also distributed with certain software (including
 *  but not limited to OpenSSL) that is licensed under separate terms,
 *  as designated in a particular file or component or in included license
 *  documentation.  The authors of MySQL hereby grant you an additional
 *  permission to link the program and your derivative works with the
 *  separately licensed software that they have included with MySQL.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License, version 2.0, for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package testsuite.clusterj.model;

import com.mysql.clusterj.annotation.PersistenceCapable;

/** Schema
 *
drop table if exists charsetswedishutf8;
create table charsetswedishutf8 (
 id int not null primary key,
 swedishcolumn char(4) COLLATE latin1_swedish_ci,
 utfcolumn char(4) COLLATE utf8_general_ci
) ENGINE=ndbcluster;

*/

@PersistenceCapable(table="charsetswedishutf8")
public interface CharsetSwedishUtf8 extends IdBase {

    public int getId();
    public void setId(int id);

    public String getSwedishColumn();
    public void setSwedishColumn(String value);

    public String getUtfColumn();
    public void setUtfColumn(String value);

}

==> percona-xtrabackup_8.0.35-30.orig.tar.gz: percona-xtrabackup-8.0.35-30/storage/ndb/clusterj/clusterj-test/src/main/java/testsuite/clusterj/model/CharsetSwedishUtf8.java <==
/*
 *  Copyright (c) 2014, 2023, Oracle and/or its affiliates.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2.0,
 *  as published by the Free Software Foundation.
 *
 *  This program is also distributed with certain software (including
 *  but not limited to OpenSSL) that is licensed under separate terms,
 *  as designated in a particular file or component or in included license
 *  documentation.  The authors of MySQL hereby grant you an additional
 *  permission to link the program and your derivative works with the
 *  separately licensed software that they have included with MySQL.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License, version 2.0, for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package testsuite.clusterj.model;

import com.mysql.clusterj.annotation.PersistenceCapable;

/** Schema
 *
drop table if exists charsetswedishutf8;
create table charsetswedishutf8 (
 id int not null primary key,
 swedishcolumn char(4) COLLATE latin1_swedish_ci,
 utfcolumn char(4) COLLATE utf8mb3_general_ci
) ENGINE=ndbcluster;

*/

@PersistenceCapable(table="charsetswedishutf8")
public interface CharsetSwedishUtf8 extends IdBase {

    public int getId();
    public void setId(int id);

    public String getSwedishColumn();
    public void setSwedishColumn(String value);

    public String getUtfColumn();
    public void setUtfColumn(String value);

}
